Trace class

An individual error with its corresponding stack trace if available.

Mixed-in types
Annotations

Constructors

Trace({required ExceptionInfo exception, Iterable<Frame> frames = const [], String? rawTrace})
const
Trace.fromMap(JsonMap map)
factory

Properties

exception → ExceptionInfo
final
frames → Iterable<Frame>
final
hashCode → int
The hash code for this object.
no setterinherited
isTrace → bool
no setterinherited
rawTrace → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
traces → Iterable<Trace>
no setterinherited

Methods

copyWith({ExceptionInfo? exception, List<Frame>? frames, String? rawTrace}) → Trace
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → JsonMap
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited